#!/usr/bin/env python3

# This value is not the one controlling the version in the (GitLab) pipeline
# This value is only necessary for automated pickup, and for manual deployments to PyPI
version = '0.3.0'
