#!/usr/bin/env python3

# Imports of module(s) internal to this project/package
from blackjack.cli import cli  # pragma: no cover


if __name__ == '__main__':
    # Just pass on to the cli-function in the
    # 'blackjack/cli.py' file, and let it be the 'main()' function.
    cli()
